@@ -1,5 +1,5 @@
 """
-Copyright © 2020-2023 Ralph Seichter
+Copyright © 2020-2024 Ralph Seichter
 
 This file is part of "Fangfrisch".
 
@@ -16,12 +16,13 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
 """
-__version__ = '1.6.1'
+__version__ = '1.8.1'
 
 
 class ClamavItem:
-    def __init__(self, section, option, url, check, path, interval, max_size, on_update) -> None:
+    def __init__(self, section, option, url, check, path, interval, max_size, on_update, connection_timeout) -> None:
         self.check = check
+        self.connection_timeout = connection_timeout
         self.interval = interval
         self.max_size = max_size
         self.on_update = on_update
