@@ -1,5 +1,5 @@
 """
-Copyright © 2020-2023 Ralph Seichter
+Copyright © 2020-2024 Ralph Seichter
 
 This file is part of "Fangfrisch".
 
@@ -22,16 +22,18 @@ import unittest
 from fangfrisch.download import _download
 from tests import FangfrischTest
 from tests import MAX_SIZE
+from tests import NETWORK_TESTS
 from tests import URL_SHA256
 
 
+@unittest.skipUnless(NETWORK_TESTS, 'network tests disabled')
 class DownloadTests(FangfrischTest):
     def test_get_ok(self):
-        d = _download(URL_SHA256, MAX_SIZE)
+        d = _download(URL_SHA256, MAX_SIZE, 10)
         self.assertTrue(d.ok)
 
     def test_get_oversized(self):
-        d = _download(URL_SHA256, 1)
+        d = _download(URL_SHA256, 1, 10)
         self.assertFalse(d.ok)
 
 
